@@ -640,16 +640,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 23
+#define MYSQL_VERSION_PATCH 24
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.23"
+#define PACKAGE_STRING "MySQL Server 10.1.24"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.23"
-#define VERSION "10.1.23"
+#define PACKAGE_VERSION "10.1.24"
+#define VERSION "10.1.24"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
@@ -673,21 +673,4 @@
 #define __STDC_FORMAT_MACROS
 #endif
 
-/*
-  stat structure (from <sys/stat.h>) is conditionally defined
-  to have different layout and size depending on the defined macros.
-  The correct macro is defined in my_config.h, which means it MUST be
-  included first (or at least before <features.h> - so, practically,
-  before including any system headers).
-
-  Check the include order by looking at __GLIBC__ (defined in <features.h>)
-
-  But we cannot force all third-party clients/connectors to include
-  my_config.h first. So, their crashes are their responsibility,
-  we enable this check only for MariaDB sources (SAFE_MUTEX check).
-*/
-#if defined(__GLIBC__) && defined(SAFE_MUTEX)
-#error <my_config.h> MUST be included first!
-#endif
-
 #endif
